@@ -18,7 +18,7 @@ use Sub::Exporter -setup =>
 	};
 	
 use vars qw ($VERSION);
-$VERSION     = '0.09';
+$VERSION     = '0.10';
 }
 
 #-------------------------------------------------------------------------------
@@ -46,7 +46,7 @@ use Data::HexDump::Range::Format ;
 
 =head1 NAME
 
-Data::HexDump::Range - Hexadecial Range Dumper
+Data::HexDump::Range - Hexadecial Range Dumper with, color, bitfields and skip ranges
 
 =head1 SYNOPSIS
 
@@ -441,10 +441,45 @@ a subroutine definition.
 
 =head4 'range' sub ref
 
-  sub whole_range(['whole range', 5, 'on_yellow']}
+  sub define_range(['whole range', 5, 'on_yellow']}
   
-  $hdr->dump([\&whole_range], $data) ; #note this is very different from L<User defined range generator>
+  $hdr->dump([\&define_range], $data) ;
 
+
+=head2 define_range($data, $offset)
+
+Returns a range description for the next range to dump
+
+I<Arguments> - See L<gather>
+
+=over 2
+
+=item * $self - A Data::HexDump::Range object
+
+=item * $data - Binary string - the data passed to the I<dump> method
+
+=item * $offset - Integer - current offset in $data
+
+=back
+
+I<Returns> - 
+
+=over 2
+
+=item * $range - An array reference containing a name, size and color and user_information
+
+OR
+
+=item * undef - Ignore this range
+
+=item * $comment - String - an optional comment that will be displayed if DUMP_RANGE_DESCRIPTION is set.
+
+=back
+
+=head4
+
+Note this is, very, different from L<User defined range generator> below.
+ 
 =head3  User defined range generator
 
 A subroutine reference can be passed as a range definition. The subroutine will be called repetitively
@@ -474,6 +509,8 @@ I<Arguments> - See L<gather>
 
 =over 2
 
+=item * $self - A Data::HexDump::Range object
+
 =item * $data - Binary string - the data passed to the I<dump> method
 
 =item * $offset - Integer - current offset in $data
@@ -504,39 +541,8 @@ Subroutines prefixed with B<[P]> are not part of the public API and shall not be
 
 =cut
 
-
 #-------------------------------------------------------------------------------
 
-Readonly my $NEW_ARGUMENTS => 	
-	[
-	qw(
-	NAME INTERACTION VERBOSE
-	
-	DUMP_RANGE_DESCRIPTION
-	
-	FORMAT 
-	COLOR 
-	OFFSET_FORMAT 
-	DATA_WIDTH 
-	DISPLAY_COLUMN_NAMES
-	DISPLAY_RULER
-	DISPLAY_OFFSET 
-	DISPLAY_CUMULATIVE_OFFSET
-	DISPLAY_ZERO_SIZE_RANGE_WARNING
-	DISPLAY_ZERO_SIZE_RANGE 
-	DISPLAY_RANGE_NAME
-	MAXIMUM_RANGE_NAME_SIZE
-	DISPLAY_RANGE_SIZE
-	DISPLAY_ASCII_DUMP
-	DISPLAY_HEX_DUMP
-	DISPLAY_DEC_DUMP
-	DISPLAY_USER_INFORMATION
-	DISPLAY_BITFIELDS
-	DISPLAY_BITFIELD_SOURCE
-	COLOR_NAMES 
-	ORIENTATION 
-	)] ;
-
 sub new
 {
 
@@ -580,7 +586,9 @@ Useful if you use Data::HexDump::Range in an application without terminal.
 
 =item * VERBOSE - Boolean - Display information about the creation of the object. Default is I<false>
 
-=item * DUMP_RANGE_DESCRIPTION - Boolean - Diplays the range descritption. A debugging flag.
+=item * DUMP_RANGE_DESCRIPTION - Boolean - Diplays the processed range descritption in plain text before the dump
+
+=item * DUMP_ORIGINAL_RANGE_DESCRIPTION - Boolean - Diplays the un-processed range descritption. A debugging flag.
 
 =item * FORMAT - String - format of the dump string generated by Data::HexDump::Range.
 
@@ -616,6 +624,8 @@ in base 10. Default is 'hex'.
 
 =item * DISPLAY_ZERO_SIZE_RANGE_WARNING - Boolean - if set, a warning is emitted if ranges that do not consume data. Default is I<true> 
 
+=item * DISPLAY_COMMENT_RANGE - Boolean - if set, comment ranges are displayed. default is I<true> 
+
 =item * DISPLAY_RANGE_SIZE - Bolean - if set the range size is prepended to the name. Default I<false>
 
 =item * DISPLAY_ASCII_DUMP - Boolean - If set, the ASCII representation of the binary data is displayed. Default is I<true>
@@ -624,7 +634,13 @@ in base 10. Default is 'hex'.
 
 =item * DISPLAY_DEC_DUMP - Boolean - If set, the decimall dump column is displayed. Default is I<false>
 
-=item * DISPLAY_BITFIELD_SOURCE - Boolean - if set an extra column indicataing the source of bitfields is displayed
+=item * DISPLAY_BITFIELD_SOURCE - Boolean - if set an extra column indicating the source of bitfields is displayed
+
+=item * MAXIMUM_BITFIELD_SOURCE_SIZE - Integer - maximum size of the bifield source column 
+
+=item * DISPLAY_USER_INFORMATION - Boolean - if set an extra column displaying user supplied information is shown
+
+=item * MAXIMUM_USER_INFORMATION_SIZE - Integer - maximum size of theuser information column 
 
 =item * DISPLAY_BITFIELDS - Boolean - if set the bitfields are displayed
 
@@ -659,7 +675,7 @@ I<Exceptions> - Dies if an unsupported option is passed.
 my ($invocant, @setup_data) = @_ ;
 
 my $class = ref($invocant) || $invocant ;
-confess 'Invalid constructor call!' unless defined $class ;
+confess 'Error: Invalid constructor call' unless defined $class ;
 
 my $object = {} ;
 
